AnalysisOutputDef class

Definition of an expected analysis output artifact.

Constructors

AnalysisOutputDef({required AnalysisArtifactType type, required String name, Map<String, dynamic>? parameters})
Cannot be const due to Map<String, dynamic> field.
AnalysisOutputDef.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Name for the output artifact.
final
parameters Map<String, dynamic>?
Optional output-specific parameters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AnalysisArtifactType
Type of artifact to produce.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited