AnalysisSpecMetadata class

Metadata associated with an analysis specification.

Constructors

AnalysisSpecMetadata({String? author, List<String> tags = const [], String? description})
const
AnalysisSpecMetadata.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

author String?
Author of the specification.
final
description String?
Human-readable description of the specification.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
Tags for categorization and search.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited