AssetPort class abstract

Port for asset retrieval.

Constructors

AssetPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAsset(String id) Future<AssetContent>
Get an asset by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamAsset(String id) Stream<List<int>>
Open a byte stream to an asset.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited