consumerPackVariant property
Selects the BuildTarget.consumerPack shape. Defaults to ConsumerPackVariant.ragOnly when the target is requested without an explicit choice.
Implementation
final ConsumerPackVariant? consumerPackVariant;
Selects the BuildTarget.consumerPack shape. Defaults to ConsumerPackVariant.ragOnly when the target is requested without an explicit choice.
final ConsumerPackVariant? consumerPackVariant;