BuildResult class

Outcome of Converter.run.

Constructors

BuildResult({required bool success, required List<BuildArtifact> artifacts, required List<String> warnings, ValidationReport? validationReport, Object? error})
const

Properties

artifacts List<BuildArtifact>
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
false when validation produced errors or a target threw.
final
validationReport ValidationReport?
final
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited