BuildTarget enum

Output kinds. Multiple may be requested in one run.

Inheritance
Available extensions

Values

mbd → const BuildTarget

Plain <outDir>/mbd/ directory (McpBundleWriter.writeDirectory).

mcpb → const BuildTarget

Zip archive <outDir>/mcpb/<name>.mcpb.

embedded → const BuildTarget

Bundle with inline embeddings written to <outDir>/embedded/.

consumerPack → const BuildTarget

Consumer-shape pack written to <outDir>/consumer-pack/. Selected variant determined by BuildRequest.consumerPackVariant.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BuildTarget>
A constant List of the values in this enum, in order of their declaration.