BundleDependency class

Dependency on another bundle.

Constructors

BundleDependency({required String id, required String version, bool optional = false, List<String> features = const []})
const
BundleDependency.fromJson(Map<String, dynamic> json)
factory

Properties

features List<String>
Required features from the dependency.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Bundle identifier.
final
optional bool
Whether this dependency is optional.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Version constraint (semver).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited