BundleInstallStore class abstract interface

A collection of installed bundles.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginInstall(String id) Future<BundleStagingArea>
Open a staging area to write a new copy of id into.
listInstalled() Future<List<String>>
Ids of bundles that are fully installed.
locatorOf(String id) String
Locator for id in this store's own terms — an absolute path for a filesystem store, a storage key for a remote one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInstalled(String id) Future<BundleFileStore?>
File surface of installed bundle id, or null when not installed.
remove(String id) Future<void>
Remove installed bundle id. No-op when it is not installed.
toString() String
A string representation of this object.
inherited
withLock<T>(Future<T> body()) Future<T>
Run body with this store held exclusively.

Operators

operator ==(Object other) bool
The equality operator.
inherited