BundleLoader class

Loads and parses MCP bundles from various sources.

Constructors

BundleLoader({LoaderOptions options = const LoaderOptions()})

Properties

hashCode int
The hash code for this object.
no setterinherited
options LoaderOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() → void
Clear the cache.
getCached(String name) Bundle?
Get a cached bundle by name.
isCached(String name) bool
Check if a bundle is cached.
load(BundleSource source) Future<LoadResult<Bundle>>
Load a bundle from a source.
loadFromJson(Map<String, dynamic> json) Future<LoadResult<Bundle>>
Load a bundle from JSON data.
loadFromString(String content) Future<LoadResult<Bundle>>
Load a bundle from a JSON string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromCache(String name) → void
Remove a bundle from cache.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited