BundleMissingFieldException class

Missing required field error.

Inheritance

Constructors

BundleMissingFieldException(String fieldPath)

Properties

cause → dynamic
Underlying cause of the error.
finalinherited
fieldPath String
Path to the missing field.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited