BundleParseException class

JSON parsing error with location information.

Inheritance

Constructors

BundleParseException(String message, {int? line, int? column})

Properties

cause → dynamic
Underlying cause of the error.
finalinherited
column int?
Column number where error occurred.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
Line number where error occurred.
final
message String
Error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited