BundleReader class

Constructors

BundleReader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

read(String mbdPath) Future<McpBundle>
Read mbdPath and return its parsed McpBundle. Throws ArgumentError when the directory or manifest is missing, FormatException when the manifest is not valid JSON.