BundleType enum

Bundle types.

Inheritance
Available extensions

Values

application → const BundleType

Full application bundle.

library → const BundleType

Library/component bundle.

skill → const BundleType

Skill-only bundle.

profile → const BundleType

Profile-only bundle.

extension → const BundleType

Extension bundle.

unknown → const BundleType

Unknown type.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) BundleType

Constants

values → const List<BundleType>
A constant List of the values in this enum, in order of their declaration.