CommandResult class

Result of a command execution.

Constructors

CommandResult({required CommandStatus status, dynamic result, IoError? error, PolicyTrace? policyTrace})
CommandResult.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

error IoError?
Error information (if failed).
final
hashCode int
The hash code for this object.
no setterinherited
policyTrace PolicyTrace?
Policy evaluation trace.
final
result → dynamic
Result value (if completed successfully).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CommandStatus
Status of the command.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited