ConfidenceThresholdConfig class

Configuration for confidence threshold behavior in appraisal.

Constructors

ConfidenceThresholdConfig({double minConfidenceThreshold = 0.3, double fallbackThreshold = 0.2, bool triggerEvidenceOnLowConfidence = true, double evidenceTriggerThreshold = 0.5})
const
ConfidenceThresholdConfig.fromJson(Map<String, dynamic> json)
factory

Properties

evidenceTriggerThreshold double
Confidence threshold for triggering evidence requirement (default: 0.5).
final
fallbackThreshold double
Confidence below which metric is replaced with defaultValue (default: 0.2).
final
hashCode int
The hash code for this object.
no setterinherited
minConfidenceThreshold double
Minimum confidence required for metric to be used (default: 0.3).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerEvidenceOnLowConfidence bool
Whether low confidence triggers require_evidence modifier (default: true).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited