DomainAction class

domainActions[] entry — discriminated by kind. Either a single-click button (carries tool/icon/tooltip/args) or a selectGroup (carries stateKey/items). Hosts switch on kind to render.

Constructors

DomainAction({required DomainActionKind kind, String? tool, String? icon, String? tooltip, Map<String, dynamic>? args, String? stateKey, List<DomainActionSelectItem> items = const []})
const
DomainAction.fromJson(Map<String, dynamic> json)
factory

Properties

args Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
items List<DomainActionSelectItem>
final
kind DomainActionKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateKey String?
final
tool String?
final
tooltip String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited