EmbeddedPolicyRule class

A rule within an embedded policy.

Constructors

EmbeddedPolicyRule({required String id, required String condition, required String action, Map<String, dynamic> parameters = const {}})
const
EmbeddedPolicyRule.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

action String
Action to take when condition is met.
final
condition String
Condition expression.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Rule identifier.
final
parameters Map<String, dynamic>
Action parameters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited