EmbeddingConfig class

Embedding configuration.

Constructors

EmbeddingConfig({required String model, int? dimensions, int batchSize = 100})
const
EmbeddingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

batchSize int
Batch size.
final
dimensions int?
Embedding dimensions.
final
hashCode int
The hash code for this object.
no setterinherited
model String
Embedding model.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited