EthosMetadata class

Version, author, timestamps, context metadata for an Ethos.

Annotations
  • @immutable

Constructors

EthosMetadata({required String version, String? author, required DateTime createdAt, required DateTime updatedAt, String? context, List<String> tags = const []})
const
EthosMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

author String?
Creator/maintainer.
final
context String?
Usage context description.
final
createdAt DateTime
Creation timestamp.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
Categorization tags.
final
updatedAt DateTime
Last update timestamp.
final
version String
Semantic version of this Ethos.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited