EvolutionRecord class

A record of an evolution event for audit and history.

Annotations
  • @immutable

Constructors

EvolutionRecord({required String id, required String ethosId, required EvolutionProposal proposal, required ProposalStatus finalStatus, String? reviewerNote, DateTime? recordedAt})
EvolutionRecord.fromJson(Map<String, dynamic> json)
factory

Properties

ethosId String
final
finalStatus ProposalStatus
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
proposal EvolutionProposal
final
recordedAt DateTime
final
reviewerNote String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited