ExtractionValidator class
Validator for extracted FactGraph data.
Constructors
-
ExtractionValidator({required String id, required String targetType, List<
ValidationRule> rules = const []}) -
const
-
ExtractionValidator.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Validator identifier.
final
-
rules
→ List<
ValidationRule> -
Validation rules.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetType → String
-
Target type to validate.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited