FactQuery class

Query descriptor for FactsPort.queryFacts.

Constructors

FactQuery({required String workspaceId, List<String>? types, String? entityId, Period? period, DateTime? asOf, int? limit, Map<String, dynamic>? filters})
const

Properties

asOf DateTime?
Point in time.
final
entityId String?
Entity identifier filter.
final
filters Map<String, dynamic>?
Custom filters.
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum results.
final
period Period?
Time period filter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types List<String>?
Fact types to include.
final
workspaceId String
Workspace identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited