FlowParameter class

Flow parameter definition.

Constructors

FlowParameter({required String name, required String type, bool required = false, dynamic defaultValue, String? description, Map<String, dynamic>? validation})
const
FlowParameter.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → dynamic
Default value.
final
description String?
Description.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Parameter name.
final
required bool
Whether required.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Parameter type.
final
validation Map<String, dynamic>?
Validation schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited