FlowSection class

Flow section containing flow definitions.

Constructors

FlowSection({String schemaVersion = '1.0.0', List<FlowDefinition> flows = const [], Map<String, dynamic> sharedState = const {}, List<ErrorHandler> errorHandlers = const []})
const
FlowSection.fromJson(Map<String, dynamic> json)
factory

Properties

errorHandlers List<ErrorHandler>
Error handlers.
final
flows List<FlowDefinition>
List of flow definitions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
Schema version for flow section.
final
sharedState Map<String, dynamic>
Shared variables accessible across flows.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited