FormSection class

A section within a form document.

Constructors

FormSection({required String sectionId, required int index, String? title, String? description, List<FormBlock> blocks = const []})
const
FormSection.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

blocks List<FormBlock>
Blocks within this section.
final
description String?
Optional section description.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Section ordering index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionId String
Unique section identifier.
final
title String?
Optional section title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited