GoldVerdict class

Per-question result.

Constructors

GoldVerdict({required GoldQuestion question, required bool passed, required List<BmHit> hits, String? reason})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hits List<BmHit>
final
passed bool
final
question GoldQuestion
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited