IntegrityConfig class

Integrity configuration for bundle verification.

Constructors

IntegrityConfig({ContentHash? contentHash, List<FileHash> files = const [], List<Signature> signatures = const [], DateTime? computedAt})
const
IntegrityConfig.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

computedAt DateTime?
Timestamp of integrity computation.
final
contentHash → ContentHash?
Content hash of the bundle.
final
files List<FileHash>
Individual file hashes.
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Check if integrity configuration is valid.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatures List<Signature>
Digital signatures.
final

Methods

copyWith({ContentHash? contentHash, List<FileHash>? files, List<Signature>? signatures, DateTime? computedAt}) IntegrityConfig
Create a copy with modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited