IntegrityError class

Integrity error.

Constructors

IntegrityError({required IntegrityErrorType type, String? path, required String message, String? expectedHash, String? actualHash})
const

Properties

actualHash String?
Actual hash.
final
expectedHash String?
Expected hash.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error message.
final
path String?
Resource path with the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IntegrityErrorType
Error type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited