IoAuditExportConfig class

Configuration for exporting audit records to an external system.

Constructors

IoAuditExportConfig({required IoAuditQuery query, required String targetSystem, Map<String, dynamic>? options})
const
IoAuditExportConfig.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
options Map<String, dynamic>?
Additional export options.
final
query IoAuditQuery
Query filter for selecting records to export.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSystem String
Target system identifier (e.g., "mcp_fact_graph", "elasticsearch").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited