KernelClientConnection class abstract

A configured outbound connection. Hosts surface one of these per remote server the kernel has been pointed at.

Constructors

KernelClientConnection()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Host-assigned identifier (URL, label, etc).
no setter
isConnected bool
true when the underlying transport is currently attached.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callTool(String name, Map<String, dynamic> args) Future<KernelToolResult>
close() Future<void>
listResources() Future<List<KernelResourceDescriptor>>
listTools() Future<List<KernelToolDescriptor>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readResource(String uri) Future<KernelReadResourceResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited