LoaderOptions class

Options for loading bundles.

Constructors

LoaderOptions({bool validate = true, bool resolveRefs = true, bool loadDependencies = true, int maxDepth = 10, String? basePath, ContentResolver? contentResolver, DependencyResolver? dependencyResolver, bool cache = true, bool allowMissingOptional = true})
const
LoaderOptions.lenient()
Create options for lenient loading.
factory
LoaderOptions.strict()
Create options for strict loading.
factory

Properties

allowMissingOptional bool
Whether to allow missing optional dependencies.
final
basePath String?
Base path for resolving relative paths.
final
cache bool
Whether to cache loaded bundles.
final
contentResolver ContentResolver?
Custom content resolver.
final
dependencyResolver DependencyResolver?
Dependency resolver.
final
hashCode int
The hash code for this object.
no setterinherited
loadDependencies bool
Whether to load dependencies.
final
maxDepth int
Maximum depth for dependency resolution.
final
resolveRefs bool
Whether to resolve external content references.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validate bool
Whether to validate the bundle after loading.
final

Methods

copyWith({bool? validate, bool? resolveRefs, bool? loadDependencies, int? maxDepth, String? basePath, ContentResolver? contentResolver, DependencyResolver? dependencyResolver, bool? cache, bool? allowMissingOptional}) LoaderOptions
Create a copy with modifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited