LoggingConfig class

Logging configuration.

Constructors

LoggingConfig({LogLevel level = LogLevel.info, bool includeStackTrace = false, bool enableAuditLog = false})
const

Properties

enableAuditLog bool
Enable audit logging.
final
hashCode int
The hash code for this object.
no setterinherited
includeStackTrace bool
Include stack traces.
final
level LogLevel
Log level.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited