McpToolRef class

MCP tool reference.

Constructors

McpToolRef({required String serverId, required String toolName, bool required = true})
const
McpToolRef.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
required bool
Required/optional.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId String
Server ID.
final
toolName String
Tool name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited