MemorySkillRegistry class

In-memory implementation of SkillBundleRegistry.

Implemented types

Constructors

MemorySkillRegistry()

Properties

count int
Get count of registered bundles.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all registered bundles.
getSkill(String skillId) Future<SkillBundle?>
Get a skill bundle by ID.
override
has(String skillId) bool
Check if a bundle exists.
isEnabled(String skillId, {String? workspaceId}) Future<bool>
Check if a skill is enabled.
override
listSkills({String? workspaceId}) Future<List<SkillBundle>>
List all registered skill bundles.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerSkill(SkillBundle bundle) Future<void>
Register a skill bundle.
override
setEnabled(String skillId, bool enabled, {String? workspaceId}) Future<void>
Enable or disable a skill.
override
toString() String
A string representation of this object.
inherited
unregisterSkill(String skillId) Future<void>
Unregister a skill bundle by ID.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited