MutationOutcome<R> class
Result returned from a McpBundleMutator.mutate closure.
updated == null signals a no-op — the disk write is skipped. Use
to abort cleanly when the inspection step determines the requested
mutation is a no-op without raising an error.
Constructors
- MutationOutcome({McpBundle? updated, required R result})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited