NullCoalesceExpr class

Null coalescing expression (left ?? right).

Inheritance

Constructors

NullCoalesceExpr(Expr left, Expr right)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left Expr
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<T>(ExprVisitor<T> visitor) → T
Accept a visitor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited