OcrResult class

OCR recognition result.

Constructors

OcrResult({required String text, required double confidence, String? language, List<OcrRegion>? regions, required Duration processingTime})
const

Properties

confidence double
Confidence score (0.0 - 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
language String?
Detected language.
final
processingTime Duration
Processing time.
final
regions List<OcrRegion>?
Text regions with bounding boxes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Recognized text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited