ProfileApplicationResult class

Complete profile application result per design/03-runtime.md 5.

Constructors

ProfileApplicationResult({required String profileId, required String contextId, required AppraisalResult appraisal, required DecisionGuidance decision, required ExpressionStyle expression, FormattedResponse? formatted, required ProfileApplicationMetadata metadata})
const

Properties

appraisal AppraisalResult
Appraisal result with metrics.
final
contextId String
Context ID for this execution.
final
decision DecisionGuidance
Decision guidance from policy evaluation.
final
expression ExpressionStyle
Expression style determined by policies.
final
formatted → FormattedResponse?
Formatted response if content was provided.
final
hashCode int
The hash code for this object.
no setterinherited
metadata ProfileApplicationMetadata
Execution metadata.
final
profileId String
Profile ID that was applied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited