ProfileConfig class

Profile configuration.

Constructors

ProfileConfig({bool enableAppraisalByDefault = true, double appraisalThreshold = 70.0, int maxContentLength = 100000, String conflictResolution = 'merge'})
const

Properties

appraisalThreshold double
Appraisal threshold.
final
conflictResolution String
Conflict resolution strategy for multi-profile scenarios.
final
enableAppraisalByDefault bool
Enable appraisal by default.
final
hashCode int
The hash code for this object.
no setterinherited
maxContentLength int
Maximum content length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited