ResourceType enum

Types of resources that can be in a bundle.

Inheritance
Available extensions

Values

skill → const ResourceType

Skill definition.

profile → const ResourceType

Profile definition.

factGraph → const ResourceType

Fact graph data.

knowledgeOps → const ResourceType

Knowledge operations.

data → const ResourceType

Raw data file.

config → const ResourceType

Configuration file.

template → const ResourceType

Template file.

schema → const ResourceType

Schema definition.

unknown → const ResourceType

Unknown resource type.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ResourceType
Parse from string.

Constants

values → const List<ResourceType>
A constant List of the values in this enum, in order of their declaration.