StepResult class

Result from a single step execution.

Constructors

StepResult({required String stepId, required dynamic result, List<Claim> claims = const [], List<String> evidenceRefs = const [], String? toolCalled, Map<String, dynamic>? metadata})
const
StepResult.fromJson(Map<String, dynamic> json)
Create from JSON.
factory

Properties

claims List<Claim>
Claims from this step.
final
evidenceRefs List<String>
Evidence references.
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
Step metadata.
final
result → dynamic
Step result value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepId String
Step ID.
final
toolCalled String?
Tool called (if any).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited