StubAuditPort class

Stub implementation for testing.

Implemented types

Constructors

StubAuditPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(AuditFilter filter) Future<List<AuditEvent>>
Query audit events.
override
record(AuditEvent event) Future<void>
Record an audit event.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited