StubPhilosophyPort class

Stub philosophy port for testing.

Implemented types

Constructors

StubPhilosophyPort()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkProhibitions(ProhibitionCheckRequest request) Future<ProhibitionCheckResult>
Check a proposed action or output against all prohibitions.
override
detectTensions(MultiLayerContext context) Future<List<Tension>>
Detect tensions between Philosophy and other layers.
override
evaluate(PhilosophyEvaluationContext context) Future<PhilosophyGuidance>
Evaluate the current context against the active Ethos.
override
getEthos() Future<Ethos>
Retrieve the currently active Ethos instance.
override
intervene(InterventionPoint point, PipelineContext context) Future<InterventionResult>
Apply philosophy intervention at a pipeline stage.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
proposeFeedback(FeedbackEvent event) Future<EvolutionProposal?>
Generate an evolution proposal from action feedback.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited