TestStepAction enum

Step actions.

Inheritance
Available extensions

Values

execute → const TestStepAction
click → const TestStepAction
input → const TestStepAction
wait → const TestStepAction
assert_ → const TestStepAction
mock → const TestStepAction
restore → const TestStepAction
unknown → const TestStepAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) TestStepAction

Constants

values → const List<TestStepAction>
A constant List of the values in this enum, in order of their declaration.