Token class

A token produced by the lexer.

Constructors

Token({required TokenType type, required String lexeme, dynamic literal, required int line, required int column})
const

Properties

column int
final
hashCode int
The hash code for this object.
no setteroverride
lexeme String
final
line int
final
literal → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TokenType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override