UndoSnapshot class

Snapshot of the entire stack — undo + redo halves, in their natural stack order (top-of-stack last).

Constructors

UndoSnapshot({required List<UndoFrameSnapshot> undoFrames, required List<UndoFrameSnapshot> redoFrames})
const
UndoSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
redoFrames List<UndoFrameSnapshot>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
undoFrames List<UndoFrameSnapshot>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const UndoSnapshot