AudioContent class

Audio content (spec 2025-03-26+).

Inheritance
Annotations
  • @immutable

Constructors

AudioContent({required String data, required String mimeType, Map<String, dynamic>? annotations})
const
AudioContent.fromJson(Map<String, dynamic> json)
factory

Properties

annotations → Map<String, dynamic>?
final
data → String
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited