AuthServerMetadata class
Authorization server metadata (RFC8414)
- Annotations
-
- @immutable
Constructors
-
AuthServerMetadata({required String issuer, required String authorizationEndpoint, required String tokenEndpoint, List<
String> tokenEndpointAuthMethodsSupported = const ['client_secret_basic'], List<String> responseTypesSupported = const ['code'], List<String> grantTypesSupported = const ['authorization_code', 'refresh_token'], List<String> codeChallengeMethodsSupported = const ['S256'], String? registrationEndpoint, String? revocationEndpoint, String? introspectionEndpoint}) -
const
-
AuthServerMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
Authorization endpoint
final
-
codeChallengeMethodsSupported
→ List<
String> -
Code challenge methods supported
final
-
grantTypesSupported
→ List<
String> -
Grant types supported
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- introspectionEndpoint → String?
-
Introspection endpoint
final
- issuer → String
-
Issuer identifier
final
- registrationEndpoint → String?
-
Registration endpoint
final
-
responseTypesSupported
→ List<
String> -
Response types supported
final
- revocationEndpoint → String?
-
Revocation endpoint
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenEndpoint → String
-
Token endpoint
final
-
tokenEndpointAuthMethodsSupported
→ List<
String> -
Token endpoint auth methods supported
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited