CachedResource class

Cached resource item for performance optimization

Annotations
  • @immutable

Constructors

CachedResource({required String uri, required ReadResourceResult content, required DateTime cachedAt, required Duration maxAge})
const

Properties

cachedAt DateTime
When the resource was cached
final
content ReadResourceResult
Content of the resource
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
Check if the cache entry has expired
no setter
maxAge Duration
How long the cache should be valid
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
URI of the cached resource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited