CompressedEventSource class

Compressed EventSource implementation

Constructors

CompressedEventSource()

Properties

activeCompression CompressionType
no setter
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
connect(String url, {Map<String, String>? headers, int compressionThreshold = 1024, dynamic onOpen(String?)?, dynamic onMessage(dynamic)?, dynamic onError(dynamic)?, dynamic onCompressionNegotiated(CompressionType)?}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited