error property
Object?
get
error
Returns the error if in error state, null otherwise
Implementation
Object? get error => switch (this) {
ConnectionError(error: final error) => error,
_ => null,
};
Returns the error if in error state, null otherwise
Object? get error => switch (this) {
ConnectionError(error: final error) => error,
_ => null,
};