hasToolCalls property
bool
get
hasToolCalls
Whether this sampling turn resolved to tool calls (spec 2025-11-25+).
Implementation
bool get hasToolCalls => toolCalls != null && toolCalls!.isNotEmpty;
Whether this sampling turn resolved to tool calls (spec 2025-11-25+).
bool get hasToolCalls => toolCalls != null && toolCalls!.isNotEmpty;