toolCalls property
Spec 2025-11-25+: tool calls the model requested, when the sampling turn resolved to tool use instead of a final message. Null when the model returned a normal completion.
Implementation
final List<Map<String, dynamic>>? toolCalls;