EnumElicitationField class
A single-select enum field. Carries the enumSchema (values +
optional enumNames) and an optional defaultValue (SEP-1034).
- Inheritance
-
- Object
- ElicitationFieldSchema
- EnumElicitationField
- Annotations
-
- @immutable
Constructors
- EnumElicitationField({String? title, String? description, required EnumSchema enumSchema, String? defaultValue})
-
const
-
EnumElicitationField.fromJson(Map<
String, dynamic> json) -
factory
Properties
- defaultValue → String?
-
final
- description → String?
-
Optional description (
description).finalinherited - enumSchema → EnumSchema
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional display title (
title).finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited