GetPromptRequest class

Get prompt request

Annotations
  • @immutable

Constructors

GetPromptRequest({required String name, Map<String, dynamic>? arguments})
const
GetPromptRequest.fromJson(Map<String, dynamic> json)
factory

Properties

arguments → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited