HeartbeatEventSource class
Heartbeat-enabled EventSource implementation
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
connect(
String url, {Map< String, String> ? headers, dynamic onOpen(String?)?, dynamic onMessage(dynamic)?, dynamic onError(dynamic)?, dynamic onHeartbeat(Duration)?}) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendHeartbeat(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited