HeartbeatStats class

Heartbeat statistics

Constructors

HeartbeatStats({required int totalHeartbeats, required int missedHeartbeats, required int reconnectionAttempts, required Duration averageLatency, required ConnectionHealth currentHealth, DateTime? lastHeartbeat, DateTime? lastMissedHeartbeat})
const

Properties

averageLatency Duration
final
currentHealth ConnectionHealth
final
hashCode int
The hash code for this object.
no setterinherited
lastHeartbeat DateTime?
final
lastMissedHeartbeat DateTime?
final
missedHeartbeats int
final
reconnectionAttempts int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalHeartbeats int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited