InitializeRequest class

Initialize request

Annotations
  • @immutable

Constructors

InitializeRequest({required ClientInfo clientInfo, required String protocolVersion})
const
InitializeRequest.fromJson(Map<String, dynamic> json)
factory

Properties

clientInfo → ClientInfo
final
hashCode → int
The hash code for this object.
no setterinherited
protocolVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited