InitializeResult class

Initialize result

Annotations
  • @immutable

Constructors

InitializeResult({required ServerInfo serverInfo, required String protocolVersion, Map<String, dynamic>? capabilities})
const
InitializeResult.fromJson(Map<String, dynamic> json)
factory

Properties

capabilities Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
protocolVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverInfo ServerInfo
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited