JsonRpcMessage class

JSON-RPC message

Annotations
  • @immutable

Constructors

JsonRpcMessage({required String jsonrpc, dynamic id, String? method, Map<String, dynamic>? params, dynamic result, Map<String, dynamic>? error})
const
JsonRpcMessage.fromJson(Map<String, dynamic> json)
factory

Properties

error → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → dynamic
final
isNotification → bool
no setter
isRequest → bool
no setter
isResponse → bool
no setter
jsonrpc → String
final
method → String?
final
params → Map<String, dynamic>?
final
result → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited