LogMessageNotification class

Log message notification

Annotations
  • @immutable

Constructors

LogMessageNotification({required McpLogLevel level, required String message, String? logger, Map<String, dynamic>? data})
const
LogMessageNotification.fromJson(Map<String, dynamic> json)
factory

Properties

data → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
level → McpLogLevel
final
logger → String?
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited