MultiSelectEnumElicitationField class
A multi-select enum field (SEP-1330): a JSON Schema array whose
items are an enum. Carries the shared enumSchema, an optional list
defaultValue (SEP-1034), and array constraints.
- Inheritance
-
- Object
- ElicitationFieldSchema
- MultiSelectEnumElicitationField
- Annotations
-
- @immutable
Constructors
-
MultiSelectEnumElicitationField({String? title, String? description, required EnumSchema enumSchema, List<
String> ? defaultValue, bool uniqueItems = false, int? minItems, int? maxItems}) -
const
-
MultiSelectEnumElicitationField.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
defaultValue
→ List<
String> ? -
final
- description → String?
-
Optional description (
description).finalinherited - enumSchema → EnumSchema
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxItems → int?
-
final
- minItems → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional display title (
title).finalinherited - uniqueItems → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited