OAuthClient class abstract

OAuth client interface

Constructors

OAuthClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exchangeCodeForToken({required String code, required String codeVerifier}) Future<OAuthToken>
Exchange authorization code for token
getAuthorizationUrl({required List<String> scopes, String? state, Map<String, String>? additionalParams}) Future<String>
Get authorization URL
getClientCredentialsToken({List<String>? scopes}) Future<OAuthToken>
Get token using client credentials
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken({required String refreshToken}) Future<OAuthToken>
Refresh access token
revokeToken({required String token, String? tokenTypeHint}) Future<void>
Revoke token
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited