PendingOperation class

Pending operation for cancellation support

Constructors

PendingOperation({required String id, required String sessionId, required String type, required DateTime createdAt, String? requestId})
PendingOperation.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
When the operation was created
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this operation
final
isCancelled bool
Whether this operation has been cancelled
getter/setter pair
requestId String?
Optional ID of the request that initiated this operation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
Session ID where this operation is running
final
type String
Type of the operation (e.g., "tool:calculator")
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited