ProgressUpdate class

Progress update for long-running operations

Annotations
  • @immutable

Constructors

ProgressUpdate({required String requestId, required double progress, required String message})
const
ProgressUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Optional message describing the current status
final
progress double
Progress value between 0.0 and 1.0
final
requestId String
ID of the request this progress relates to
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited