ProtocolCapabilities class

Protocol capabilities

Constructors

ProtocolCapabilities({bool experimental = false, bool tools = true, bool resources = true, bool prompts = true, bool logging = true})
const
ProtocolCapabilities.fromJson(Map<String, dynamic> json)
factory

Properties

experimental → bool
final
hashCode → int
The hash code for this object.
no setterinherited
logging → bool
final
prompts → bool
final
resources → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tools → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited