ResourceTemplate class

Resource template definition

Annotations
  • @immutable

Constructors

ResourceTemplate({required String uriTemplate, required String name, required String description, String? mimeType, List<Map<String, dynamic>>? icons})
const
ResourceTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
icons List<Map<String, dynamic>>?
Spec 2025-11-25+: visual metadata (icon objects). Previously dropped on the client — resource templates now round-trip icons like tools, resources, and prompts.
final
mimeType String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriTemplate String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited