errorOrNull method
E?
errorOrNull()
Returns the error if this is a failure, or null if this is a success
Implementation
E? errorOrNull() => failureOrNull;
Returns the error if this is a failure, or null if this is a success
E? errorOrNull() => failureOrNull;