getOrNull method
T?
getOrNull()
Returns the success value if this is a success, or null if this is a failure
Implementation
T? getOrNull() => successOrNull;
Returns the success value if this is a success, or null if this is a failure
T? getOrNull() => successOrNull;