auto constant
String
const auto
Let the model decide whether to call a tool.
Implementation
static const String auto = 'auto';
Let the model decide whether to call a tool.
static const String auto = 'auto';