ServerInfo class

Server information (2025-03-26 compliant)

Annotations
  • @immutable

Constructors

ServerInfo({required String name, required String version, String? protocolVersion, Map<String, dynamic>? capabilities, Map<String, dynamic>? metadata})
const
ServerInfo.fromJson(Map<String, dynamic> json)
factory

Properties

capabilities Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
name String
final
protocolVersion String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited