SseClientTransport class
Transport implementation using Server-Sent Events (SSE) over HTTP
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
final
-
onClose
→ Future<
void> -
Future that completes when the transport is closed
no setteroverride
- onMessage → Stream
-
Stream of incoming messages
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverUrl → String
-
final
Methods
-
close(
) → void -
Close the transport
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
dynamic message) → void -
Send a message through the transport
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited