SseCompressedClientTransport class

SSE Transport with automatic compression support

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
onClose Future<void>
Future that completes when the transport is closed
no setteroverride
onMessage Stream
Stream of incoming messages
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverUrl String
final

Methods

close() → void
Close the transport
override
getCompressionStats() Map<String, dynamic>
Get compression statistics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic message) → void
Send a message through the transport
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String serverUrl, Map<String, String>? headers, List<CompressionType>? supportedCompressions, int compressionThreshold = 1024}) Future<SseCompressedClientTransport>
Create SSE transport with compression negotiation