StdioTransportConfig class final

Inheritance
Annotations
  • @immutable

Constructors

StdioTransportConfig({required String command, List<String> arguments = const [], String? workingDirectory, Map<String, String>? environment})
const

Properties

arguments List<String>
final
command String
final
environment Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited