acknowledged property
The subset of the requested filter the server agreed to honor (from the
notifications/subscriptions/acknowledged message).
Implementation
final Future<SubscriptionFilter> acknowledged;
The subset of the requested filter the server agreed to honor (from the
notifications/subscriptions/acknowledged message).
final Future<SubscriptionFilter> acknowledged;