TokenLifecycleEvent class

Token lifecycle event.

Constructors

TokenLifecycleEvent({required TokenEventType type, required DateTime timestamp, String? tokenId, String? message, Map<String, dynamic>? metadata})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
metadata → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final
tokenId → String?
final
type → TokenEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited