ToolCallTracking class

Class to hold result of a tracked tool call

Constructors

ToolCallTracking({String? operationId, required CallToolResult result})

Properties

hashCode int
The hash code for this object.
no setterinherited
operationId String?
Operation ID for tracking progress
final
result CallToolResult
Result of the tool call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited