TransportConfig class sealed

Configuration for transport connections

Annotations
  • @immutable

Constructors

TransportConfig.sse({required String serverUrl, Map<String, String>? headers, Duration? connectionTimeout, Duration? heartbeatInterval, OAuthConfig? oauthConfig, OAuthToken? oauthToken, String? bearerToken, bool enableCompression, bool enableGzip, bool enableDeflate, int compressionLevel, int maxMissedHeartbeats})
Configuration for SSE transport with all features
const
factory
TransportConfig.stdio({required String command, List<String> arguments, String? workingDirectory, Map<String, String>? environment})
Configuration for STDIO transport
const
factory
TransportConfig.streamableHttp({required String baseUrl, Map<String, String>? headers, Duration? timeout, int? maxConcurrentRequests, bool? useHttp2, OAuthConfig? oauthConfig, bool enableCompression, Duration? heartbeatInterval, int maxMissedHeartbeats, bool terminateOnClose})
Configuration for Streamable HTTP transport with all features
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited