AuthResult class

Authentication result

Annotations
  • @immutable

Constructors

AuthResult({required bool isAuthenticated, Map<String, dynamic>? userInfo, String? error, List<String>? validatedScopes})
const
AuthResult.failure({required String? error})
Create failed authentication result
const
AuthResult.success({required Map<String, dynamic>? userInfo, List<String>? validatedScopes})
Create successful authentication result
const

Properties

error → String?
Error message if authentication failed
final
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticated → bool
Whether authentication was successful
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInfo → Map<String, dynamic>?
Authenticated user information
final
validatedScopes → List<String>?
Required scopes that were validated
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited