CachedResource class

Cached resource item for performance optimization

Constructors

CachedResource({required String uri, required ReadResourceResult content, required DateTime cachedAt, required Duration maxAge})

Properties

cachedAt → DateTime
final
content → ReadResourceResult
final
hashCode → int
The hash code for this object.
no setterinherited
isExpired → bool
no setter
maxAge → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited