CorsConfig class

CORS configuration

Annotations
  • @immutable

Constructors

CorsConfig({String allowOrigin = '*', String allowMethods = 'POST, OPTIONS, GET, DELETE', String allowHeaders = 'Content-Type, Authorization, Accept, X-Session-ID, mcp-session-id, ' 'last-event-id, MCP-Protocol-Version, Cache-Control, Mcp-Method, ' 'Mcp-Name, X-Heartbeat-Interval', String exposeHeaders = 'mcp-session-id, MCP-Protocol-Version, WWW-Authenticate', int maxAge = 86400})
const

Properties

allowHeaders String
final
allowMethods String
final
allowOrigin String
final
exposeHeaders String
Response headers a browser is allowed to read.
final
hashCode int
The hash code for this object.
no setterinherited
maxAge int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited