CreateMessageResult class

Create message result from sampling

Constructors

CreateMessageResult({required String model, String? stopReason, required String role, required Content content})
CreateMessageResult.fromJson(Map<String, dynamic> json)
factory

Properties

content → Content
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
final
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopReason → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited