ElicitationRequest class

A typed builder for the standard (form-mode) elicitation request params.

Produces the spec ElicitRequest.params shape: { message, requestedSchema: { type: "object", properties, required } }. Pass toJson to Server.requestClientElicitation. Additive over the raw-map path.

Constructors

ElicitationRequest({required String message, required Map<String, ElicitationSchema> properties, List<String> required = const []})
const
ElicitationRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
properties → Map<String, ElicitationSchema>
final
required → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited