EventMessage class

Event message with optional ID for SSE.

forGetStream marks events that were delivered on a session's standalone GET SSE stream (server-initiated notifications / broadcasts) — these are the events eligible for replay when a client reconnects the GET stream with a Last-Event-ID. Per-request POST responses are stored too (for event-id continuity) but are not replayed on a GET reconnect. targetSessionId is null for broadcast events.

Constructors

EventMessage({required Map<String, dynamic> message, String? eventId, bool forGetStream = false, String? targetSessionId})

Properties

eventId String?
final
forGetStream bool
final
hashCode int
The hash code for this object.
no setterinherited
message Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSessionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited