ImageContent class

Image content representation

Inheritance
Annotations
  • @immutable

Constructors

ImageContent({String? url, String? data, required String mimeType, Map<String, dynamic>? annotations})
const
ImageContent.fromBase64({required String base64Data, required String mimeType})
factory
ImageContent.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, dynamic>?
final
data String?
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited