requestState property
Opaque state blob passed back to the server on retry. The CLIENT MUST NOT
interpret it; it is echoed verbatim in InputResponseRequestParams.
Implementation
final String? requestState;
Opaque state blob passed back to the server on retry. The CLIENT MUST NOT
interpret it; it is echoed verbatim in InputResponseRequestParams.
final String? requestState;