McpMethods class
Standard MCP methods that must be implemented
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- callTool → const String
- completeArgument → const String
- createMessage → const String
- getPrompt → const String
- initialize → const String
- listPrompts → const String
- listResources → const String
- listResourceTemplates → const String
- listRoots → const String
- listTools → const String
- notificationCancelled → const String
- notificationMessage → const String
- notificationProgress → const String
- notificationPromptsListChanged → const String
- notificationResourcesListChanged → const String
- notificationRootsListChanged → const String
- notificationToolsListChanged → const String
- ping → const String
- readResource → const String
- setLoggingLevel → const String
- shutdown → const String
- subscribeResource → const String
- unsubscribeResource → const String