OAuthTokenValidator class
OAuth 2.1 token validator
- Implemented types
Constructors
- OAuthTokenValidator({required String introspectionEndpoint, required String clientId, required String clientSecret})
Properties
- clientId → String
-
final
- clientSecret → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- introspectionEndpoint → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
hasRequiredScopes(
List< String> tokenScopes, List<String> requiredScopes) → bool -
Check if token has required scopes
override
-
introspectToken(
String token) → Future< Map< String, dynamic> > -
Validate token introspection (RFC7662)
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateToken(
String token, {List< String> ? requiredScopes}) → Future<AuthResult> -
Validate a bearer token
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited