PendingOperation class

Pending operation for cancellation support

Constructors

PendingOperation({required String id, required String sessionId, required String type, String? requestId, Object? progressToken})

Properties

createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isCancelled ↔ bool
getter/setter pair
progressToken → Object?
The _meta.progressToken the client sent with the request, if any.
final
requestId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited