Prompt class

Prompt definition

Constructors

Prompt({required String name, String? title, required String description, required List<PromptArgument> arguments, List<Map<String, dynamic>>? icons, Map<String, dynamic>? meta})

Properties

arguments → List<PromptArgument>
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
icons → List<Map<String, dynamic>>?
final
meta → Map<String, dynamic>?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited