ResourceContentInfo class

Resource content info (used in ReadResourceResult)

Constructors

ResourceContentInfo({required String uri, String? mimeType, String? text, String? blob})
ResourceContentInfo.fromJson(Map<String, dynamic> json)
factory

Properties

blob → String?
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
uri → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited