ResourcesCapability class

Resources capability

Annotations
  • @immutable

Constructors

ResourcesCapability({bool? subscribe, bool? listChanged})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
listChanged bool?
Whether the server supports list change notifications
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribe bool?
Whether the server supports resource subscriptions
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited