get method
T
get()
Returns the success value if this is a success, or throws the error if this is a failure
Implementation
T get() => switch (this) {
Success(value: final value) => value,
Failure(error: final error) => throw error,
};