ServerHealth class

Server health information

Constructors

ServerHealth({String status = 'healthy', String? version, required bool isRunning, required int connectedSessions, required int registeredTools, required int registeredResources, required int registeredPrompts, required DateTime startTime, required Duration uptime, required Map<String, dynamic> metrics, Map<String, dynamic>? capabilities})

Properties

capabilities → Map<String, dynamic>?
final
connectedSessions → int
final
hashCode → int
The hash code for this object.
no setterinherited
isRunning → bool
final
metrics → Map<String, dynamic>
final
registeredPrompts → int
final
registeredResources → int
final
registeredTools → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
final
status → String
final
uptime → Duration
final
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited