SseServerTransport class

Transport implementation using Server-Sent Events (SSE) over HTTP

Implemented types

Constructors

SseServerTransport({required String endpoint, required String messagesEndpoint, required String host, required int port, List<int>? fallbackPorts, String? authToken, CompressionConfig? compressionConfig})

Properties

authToken → String?
final
compressionConfig → CompressionConfig?
final
endpoint → String
final
fallbackPorts → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
messagesEndpoint → String
final
onClose → Future<void>
Future that completes when the transport is closed
no setteroverride
onMessage → Stream
Stream of incoming messages
no setteroverride
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close the transport
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic message) → void
Send a message through the transport
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited