SseStreamInfo class

SSE stream information for request-specific streams

Constructors

SseStreamInfo({required StreamController<String> controller, required HttpResponse response})

Properties

controller → StreamController<String>
final
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
response → HttpResponse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited