setProtectedResourceMetadataProvider method
Register a callback the transport will invoke to populate the
.well-known/oauth-protected-resource document. Returning null
from the callback causes the route to respond with 404.
Implementation
void setProtectedResourceMetadataProvider(
Map<String, dynamic>? Function() provider) {
_protectedResourceMetadataProvider = provider;
}