toCreateTaskResult method

Map<String, dynamic> toCreateTaskResult({
  1. Map<String, dynamic>? meta,
})

CreateTaskResult = Result & Task (flat) with resultType: "task" — the value a server returns in lieu of a standard result when it elects to process the request as a task. meta merges into the result _meta.

Implementation

Map<String, dynamic> toCreateTaskResult({Map<String, dynamic>? meta}) => {
      ...toJson(),
      'resultType': 'task',
      if (meta != null) '_meta': meta,
    };