TaskStatus enum

Lifecycle status of a Task.

Inheritance
Available extensions

Values

working → const TaskStatus

The request is currently being processed.

inputRequired → const TaskStatus

The task is waiting for input (elicitation or sampling).

completed → const TaskStatus

The request completed successfully and results are available.

failed → const TaskStatus

The request failed due to a JSON-RPC error during execution.

cancelled → const TaskStatus

The request was cancelled before completion.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isTerminal bool
Whether this is a terminal status (no further transitions).
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String
The wire string per the ext-tasks schema.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWire(String s) TaskStatus

Constants

values → const List<TaskStatus>
A constant List of the values in this enum, in order of their declaration.