readOnly constant
String
const readOnly
Indicates if the tool only reads data and doesn't modify anything
Implementation
static const String readOnly = 'readOnly';
Indicates if the tool only reads data and doesn't modify anything
static const String readOnly = 'readOnly';