ToolAnnotationPresets class

Common tool annotation presets

Constructors

ToolAnnotationPresets()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

destructiveTool({String? category, ToolPriority? priority}) → Map<String, dynamic>
Destructive operation tool
experimentalTool({String? minApiVersion}) → Map<String, dynamic>
Experimental tool
heavyTool() → Map<String, dynamic>
High-resource usage tool
longRunningTool({int? estimatedDuration, String? category}) → Map<String, dynamic>
Long-running tool with progress
readOnlyTool({String? category, ToolPriority? priority}) → Map<String, dynamic>
Safe read-only tool