AnalysisEvidenceLink class
Evidence link referencing source data for a summary artifact.
Constructors
- AnalysisEvidenceLink({required String uri, String? query, AnalysisTimeRange? dataRange})
-
const
-
AnalysisEvidenceLink.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- dataRange → AnalysisTimeRange?
-
Optional time range of the referenced data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String?
-
Optional query that produced the evidence.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
URI pointing to the evidence data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited