ApprovalEvent class
Event emitted when approval status changes.
Constructors
-
ApprovalEvent({required String approvalId, required ApprovalEventType eventType, ApprovalStatus? previousStatus, required ApprovalStatus currentStatus, String? actorId, required DateTime timestamp, Map<
String, dynamic> data = const {}}) -
const
-
ApprovalEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actorId → String?
-
Who triggered the event.
final
- approvalId → String
-
Approval ID.
final
- currentStatus → ApprovalStatus
-
Current status.
final
-
data
→ Map<
String, dynamic> -
Additional event data.
final
- eventType → ApprovalEventType
-
Type of event.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- previousStatus → ApprovalStatus?
-
Previous status.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the event occurred.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited