id property
Resolved asset id when extractable from the pointer + current bundle,
else null (e.g. RFC 6902 add to - with empty list, or pointer
landing on a section root rather than a specific asset).
Implementation
final String? id;
Resolved asset id when extractable from the pointer + current bundle,
else null (e.g. RFC 6902 add to - with empty list, or pointer
landing on a section root rather than a specific asset).
final String? id;