BundleBusyException class
Raised when the install lock cannot be acquired (another installer is
running against the same installRoot).
- Inheritance
-
- Object
- BundleLoadException
- BundleBusyException
Constructors
- BundleBusyException(String installRoot)
Properties
- cause → dynamic
-
Underlying cause of the error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- installRoot → String
-
The installRoot that could not be locked.
final
- message → String
-
Error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited