BundleImportSummary class
Counts returned by KnowledgeSystem.importBundle for diagnostics.
Constructors
- BundleImportSummary({required int philosophiesAdded, required int agentsAdded, required int agentsSkipped})
-
const
Properties
- agentsAdded → int
-
final
- agentsSkipped → int
-
Agents skipped because their id already existed under the workspace.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- philosophiesAdded → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited