BundleIntegrityException class
Bundle integrity verification exception.
- Inheritance
-
- Object
- BundleLoadException
- BundleIntegrityException
Constructors
- BundleIntegrityException(String message, {required String checkType, String? expected, String? actual})
Properties
- actual → String?
-
Actual value found.
final
- cause → dynamic
-
Underlying cause of the error.
finalinherited
- checkType → String
-
Type of integrity check that failed.
final
- expected → String?
-
Expected value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited