BundleSigner class abstract
Implementations sign arbitrary payload bytes with a single key.
mcp_bundle produces the payload per SignedPayloadRef.type and
asks the signer for the detached signature value. The host is
responsible for key storage and algorithm-specific cryptographic
operations.
Constructors
Properties
- algorithm → SignatureAlgorithm
-
Algorithm recorded in
Signature.algorithm.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- keyId → String
-
Identifier recorded in
Signature.keyId.no setter - payloadRefType → PayloadRefType
-
SignedPayloadRef.typethat identifies which bytes are signed. Defaults to hashing the bundle'scontentHashvalue.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List payload) → Uint8List -
Compute the detached signature for
payload. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited