Abstract interface for bundle storage operations.
This port defines the contract for:
- Reading and writing bundle JSON data
- Reading and writing binary assets
- Checking existence and listing bundles
- Watching for changes (optional)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
Uri uri) → Future< void> - Delete bundle or asset.
-
exists(
Uri uri) → Future< bool> - Check if bundle or asset exists.
-
list(
Uri directoryUri) → Future< List< Uri> > - List bundles in directory.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAsset(
Uri uri) → Future< Uint8List> - Read asset binary data.
-
readBundle(
Uri uri) → Future< Map< String, dynamic> > - Read bundle JSON from URI.
-
toString(
) → String -
A string representation of this object.
inherited
-
watch(
Uri uri) → Stream< BundleChangeEvent> ? - Watch for changes (optional).
-
writeAsset(
Uri uri, Uint8List data) → Future< void> - Write asset binary data.
-
writeBundle(
Uri uri, Map< String, dynamic> data) → Future<void> - Write bundle JSON to URI.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited