BundleWriteException class
Bundle write exception.
- Inheritance
-
- Object
- BundleLoadException
- BundleWriteException
Constructors
- BundleWriteException(String message, {Uri? uri})
Properties
- cause → dynamic
-
Underlying cause of the error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri?
-
URI where the write failed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited