CandidateRecord class
Canonical candidate record.
Constructors
-
CandidateRecord({required String id, required String workspaceId, required String type, required Map<
String, dynamic> content, CandidateStatus status = CandidateStatus.pending, List<String> evidenceRefs = const [], double? confidence, required DateTime createdAt, String? reviewerId, String? rejectionReason}) -
const
Properties
- confidence → double?
-
Confidence score.
final
-
content
→ Map<
String, dynamic> -
Candidate content.
final
- createdAt → DateTime
-
Creation timestamp.
final
-
evidenceRefs
→ List<
String> -
Evidence references.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Candidate identifier (assigned on create).
final
- rejectionReason → String?
-
Rejection reason (when rejected).
final
- reviewerId → String?
-
Reviewer identifier when processed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CandidateStatus
-
Lifecycle status.
final
- type → String
-
Candidate type.
final
- workspaceId → String
-
Workspace identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited