ChunkingConfig class
Chunking configuration.
Constructors
- ChunkingConfig({ChunkingStrategy strategy = ChunkingStrategy.fixedSize, int chunkSize = 512, int chunkOverlap = 50, String? separator})
-
const
-
ChunkingConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- chunkOverlap → int
-
Chunk overlap.
final
- chunkSize → int
-
Chunk size.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → String?
-
Separator pattern.
final
- strategy → ChunkingStrategy
-
Chunking strategy.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited