CompositeCondition class
Composite condition combining multiple conditions.
- Inheritance
-
- Object
- PolicyCondition
- CompositeCondition
Constructors
-
CompositeCondition({required CompositeOperator operator, required List<
PolicyCondition> conditions}) -
const
-
CompositeCondition.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
conditions
→ List<
PolicyCondition> -
Child conditions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operator → CompositeOperator
-
Logical operator: "and", "or", "not".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{CompositeOperator? operator, List< PolicyCondition> ? conditions}) → CompositeCondition - Create a copy with modifications.
-
evaluate(
Map< String, dynamic> context) → bool -
Evaluate condition against context.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited