ConversationTurn class
One conversation turn (user message + assistant reply pair). Stored per
agent in ConversationStore under conv/<agentId>/turns.
Constructors
-
ConversationTurn({required String userMessage, required String assistantReply, required String model, required DateTime timestamp, TokenUsage? tokenUsage, Map<
String, Object?> ? extra}) -
const
-
ConversationTurn.fromJson(Map<
String, Object?> json) -
factory
Properties
- assistantReply → String
-
final
-
extra
→ Map<
String, Object?> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- tokenUsage → TokenUsage?
-
final
- userMessage → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited