FileStorageAdapter class
File system storage adapter implementing BundleStoragePort.
Provides bundle storage operations on the local file system. Supports both single JSON files and directory bundles (.mbd/).
- Implemented types
Constructors
- FileStorageAdapter([String? basePath])
-
Create a file storage adapter.
const
Properties
Methods
-
delete(
Uri uri) → Future< void> -
Delete bundle or asset.
override
-
exists(
Uri uri) → Future< bool> -
Check if bundle or asset exists.
override
-
list(
Uri directoryUri) → Future< List< Uri> > -
List bundles in directory.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAsset(
Uri uri) → Future< Uint8List> -
Read asset binary data.
override
-
readBundle(
Uri uri) → Future< Map< String, dynamic> > -
Read bundle JSON from URI.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
watch(
Uri uri) → Stream< BundleChangeEvent> ? -
Watch for changes (optional).
override
-
writeAsset(
Uri uri, Uint8List data) → Future< void> -
Write asset binary data.
override
-
writeBundle(
Uri uri, Map< String, dynamic> data) → Future<void> -
Write bundle JSON to URI.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited