FormTemplateDependency class
Template dependency entry.
Constructors
- FormTemplateDependency({required String componentId, required String version, String? type})
-
const
-
FormTemplateDependency.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
- componentId → String
-
Component identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Optional dependency type (e.g., 'font', 'icon', 'chart').
final
- version → String
-
Required version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited