FormValidationResult class
Result of a form document validation.
Constructors
-
FormValidationResult({required bool isValid, List<
FormValidationIssue> issues = const [], List<FormAutoFixAction> ? appliedFixes}) -
const
-
FormValidationResult.fromJson(Map<
String, dynamic> json) -
Create from JSON.
factory
Properties
-
appliedFixes
→ List<
FormAutoFixAction> ? -
Auto-fix actions that were applied.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
FormValidationIssue> -
List of validation issues found.
final
- isValid → bool
-
Whether the document is valid.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited