IndexBuildConfig class
Index build configuration.
Constructors
Properties
-
assetRefs
→ List<
String> -
Asset references to index.
final
- chunkOverlap → int?
-
Chunk overlap in characters.
final
- chunkSize → int?
-
Chunk size in characters.
final
- embeddingModel → String?
-
Embedding model to use.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ Map<
String, dynamic> ? -
Additional options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceRefs
→ List<
String> ? -
Source references.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited