InstallPolicy class
Policy flags for a single install call.
Constructors
- InstallPolicy({InstallConflictPolicy onConflict = InstallConflictPolicy.replace, bool requireIntegrity = true, bool requireSignature = false, InstallLimits limits = const InstallLimits()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limits → InstallLimits
-
Safety caps applied to ZIP entries.
final
- onConflict → InstallConflictPolicy
-
Conflict resolution for a pre-existing install.
final
- requireIntegrity → bool
-
When
true, an install without a parseableIntegrityConfigis rejected; whenfalse, integrity is only enforced if declared.final - requireSignature → bool
-
When
true, an install without at least one verified signature is rejected.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited