ProfileFacade class
Thin facade over profile.ProfileRuntime.
Constructors
- ProfileFacade({required KnowledgeSystem system})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAvailable → bool
-
Whether a profile runtime is wired.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system → KnowledgeSystem
-
Access the orchestrator.
no setter
Methods
-
apply(
String profileId, {required String entityId, Map< String, dynamic> ? inputs, Map<String, dynamic> ? metadata, String? rawContent}) → Future<ProfileApplicationResult> - Run the full appraisal → decision → expression pipeline.
-
appraise(
String profileId, {required String entityId}) → Future< ProfileApplicationResult> - Apply a profile and return only the appraisal portion.
-
get(
String profileId) → Profile? - Get a profile from the registry.
-
list(
) → List< Profile> - List all registered profiles.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Profile p) → void - Register a profile against the underlying profile.ProfileRegistry.
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String profileId) → bool - Unregister a profile.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited