ProfileRegistry class
Registry for managing profiles.
Constructors
Properties
-
active
→ List<
Profile> -
Get active profiles.
no setter
-
all
→ List<
Profile> -
Get all profiles.
no setter
- count → int
-
Get profile count.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ids
→ List<
String> -
Get all profile IDs.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clear all profiles.
-
get(
String id) → Profile? - Get a profile by ID.
-
getByTag(
String tag) → List< Profile> - Get profiles by tag.
-
getByTags(
List< String> tags) → List<Profile> - Get profiles by tags (all tags must match).
-
getResolved(
String id) → Profile? - Get a resolved profile (with parent inheritance).
-
has(
String id) → bool - Check if a profile exists.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Profile profile) → void - Register a profile.
-
registerAll(
Iterable< Profile> profiles) → void - Register multiple profiles.
-
searchByName(
String query) → List< Profile> - Search profiles by name.
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String id) → bool - Unregister a profile.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited