SkillRunHandle class
Handle for an executing or completed skill run.
Constructors
- SkillRunHandle({required String runId, required String skillId, required bool running, SkillResult? result, required DateTime startedAt, DateTime? finishedAt})
-
const
Properties
- finishedAt → DateTime?
-
Completion timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → SkillResult?
-
Final result (null when still running).
final
- runId → String
-
Run identifier.
final
- running → bool
-
Whether the run is still in progress.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillId → String
-
Skill identifier.
final
- startedAt → DateTime
-
Start timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited