SkillSection class
Skill section containing skill modules.
Constructors
-
SkillSection({String schemaVersion = '1.0.0', List<
SkillModule> modules = const [], SkillConfig? config}) -
const
-
SkillSection.fromJson(Map<
String, dynamic> json) -
factory
Properties
- config → SkillConfig?
-
Shared skill configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modules
→ List<
SkillModule> -
List of skill modules.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
Schema version for skill section.
final
-
skills
→ List<
SkillModule> -
Self-mirror alias of modules for parity with other sections
(
agents.agents·tools.tools·facts.factsetc.). Same list reference; mutations on either side are visible. additive (no shape change to JSON — toJson still emitsmodules).no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited