AuthenticatedEventSource class
Authenticated EventSource implementation
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Whether the connection is active
no setter
- response → HttpClientResponse?
-
Get the HTTP response (if available)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Close the connection
-
connect(
String url, {Map< String, String> ? headers, dynamic onOpen(String?)?, dynamic onMessage(dynamic)?, dynamic onError(dynamic)?, dynamic onEndpoint(String?)?, dynamic onAuthFailure(int, String)?}) → Future<void> - Connect to an SSE endpoint
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited