BooleanElicitationField class

A boolean field. Carries an optional defaultValue (SEP-1034).

Inheritance
Annotations
  • @immutable

Constructors

BooleanElicitationField({String? title, String? description, bool? defaultValue})
const
BooleanElicitationField.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → bool?
final
description → String?
Optional description (description).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Optional display title (title).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited