ClientCapabilities class
Client capabilities configuration
- Annotations
-
- @immutable
Constructors
- ClientCapabilities({bool roots = false, bool rootsListChanged = false, bool sampling = false, bool elicitation = false})
-
Create a capabilities object with specified settings
const
-
ClientCapabilities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- elicitation → bool
-
Elicitation support — server can request user input via
elicitation/create(spec 2025-06-18+).final - hashCode → int
-
The hash code for this object.
no setterinherited
- roots → bool
-
Root management support — server may request
roots/listand the client responds with Client.roots.final - rootsListChanged → bool
-
Whether roots list changes are sent as notifications
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampling → bool
-
Sampling support — host's LLM is reachable through this client (the
server can ask for completions via
sampling/createMessage).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert capabilities to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited