ElicitationResponse class
Typed response to an elicitation request. Serializes to the spec
{ action, content? } shape.
- Annotations
-
- @immutable
Constructors
-
ElicitationResponse({required ElicitationAction action, Map<
String, dynamic> ? content}) -
const
-
ElicitationResponse.accept(Map<
String, dynamic> ? content) -
Convenience constructor for an accepted response with
content.const - ElicitationResponse.cancel()
-
Convenience constructor for a cancelled response.
const
- ElicitationResponse.decline()
-
Convenience constructor for a declined response.
const
-
ElicitationResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- action → ElicitationAction
-
final
-
content
→ Map<
String, dynamic> ? -
Collected field values, present only for ElicitationAction.accept.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited