GenericElicitationField class
Fallback for a field shape this layer does not specialize. Preserves the raw JSON Schema fragment so nothing is lost.
- Inheritance
-
- Object
- ElicitationFieldSchema
- GenericElicitationField
- Annotations
-
- @immutable
Constructors
-
GenericElicitationField({required Map<
String, dynamic> raw}) -
const
-
GenericElicitationField.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String?
-
Optional description (
description).finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
-
raw
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional display title (
title).finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited