HeartbeatConfig class
Heartbeat configuration
Constructors
Properties
- autoReconnect → bool
-
Whether to automatically reconnect on connection failure
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Duration
-
Interval between heartbeat checks
final
- maxMissedBeats → int
-
Number of missed heartbeats before marking connection as unhealthy
final
- maxReconnectAttempts → int
-
Maximum number of reconnection attempts
final
- reconnectDelay → Duration
-
Delay between reconnection attempts
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Timeout for heartbeat response
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited