NumberElicitationField class

A numeric field (number or integer). Carries an optional defaultValue (SEP-1034).

Inheritance
Annotations
  • @immutable

Constructors

NumberElicitationField({String? title, String? description, bool integer = false, num? defaultValue, num? minimum, num? maximum})
const
NumberElicitationField.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue num?
final
description String?
Optional description (description).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
integer bool
Whether the JSON Schema type is integer (vs number).
final
maximum num?
final
minimum num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Optional display title (title).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited