OAuthConfig class
OAuth 2.1 authentication configuration
- Annotations
-
- @immutable
Constructors
-
OAuthConfig({String? authServerMetadataUrl, required String authorizationEndpoint, required String tokenEndpoint, required String clientId, String? clientSecret, String? redirectUri, List<
String> scopes = const [], OAuthGrantType grantType = OAuthGrantType.authorizationCode, String codeChallengeMethod = 'S256'}) -
const
-
OAuthConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
Authorization endpoint URL
final
- authServerMetadataUrl → String?
-
Authorization server metadata URL (RFC8414)
final
- clientId → String
-
Client ID
final
- clientSecret → String?
-
Client secret (for confidential clients)
final
- codeChallengeMethod → String
-
PKCE code challenge method
final
- grantType → OAuthGrantType
-
Grant type to use
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUri → String?
-
Redirect URI
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
Scopes to request
final
- tokenEndpoint → String
-
Token endpoint URL
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited