OAuthGrantType enum
OAuth 2.1 grant types supported by MCP
Values
-
Authorization code flow for human users
- clientCredentials → const OAuthGrantType
-
Client credentials flow for machine-to-machine
- refreshToken → const OAuthGrantType
-
Refresh token flow
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OAuthGrantType> - A constant List of the values in this enum, in order of their declaration.