ProtectedResourceMetadata class
OAuth 2.0 Protected Resource Metadata (RFC 9728), served at
/.well-known/oauth-protected-resource by a Resource Server.
- Annotations
-
- @immutable
Constructors
Properties
-
Authorization servers that can issue tokens for this resource — the
client OIDC/RFC-8414-discovers one of these to obtain a token.
final
-
bearerMethodsSupported
→ List<
String> ? -
Supported bearer token presentation methods (e.g.
header).final - hashCode → int
-
The hash code for this object.
no setterinherited
- primaryAuthorizationServer → String?
-
The first advertised authorization server, or null when none.
no setter
- resource → String
-
The protected resource's identifier (its canonical origin/URL).
final
- resourceDocumentation → String?
-
Human-readable documentation URL.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopesSupported
→ List<
String> ? -
Scopes the resource server understands (advertised, not necessarily
required per request).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited