Resource class
Resource definition
- Annotations
-
- @immutable
Constructors
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
icons
→ List<
Map< ?String, dynamic> > -
Spec 2025-11-25+: visual metadata (icon objects).
final
-
meta
→ Map<
String, dynamic> ? -
Spec 2025-06-18+: free-form
_metamap.final -
metadata
→ Map<
String, dynamic> ? -
final
- mimeType → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Spec 2025-06-18+: human-readable display name. Falls back to name.
final
- uri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited