SseTransportConfig class final

Inheritance
Annotations
  • @immutable

Constructors

SseTransportConfig({required String serverUrl, Map<String, String>? headers, Duration? connectionTimeout, Duration? heartbeatInterval, OAuthConfig? oauthConfig, OAuthToken? oauthToken, String? bearerToken, bool enableCompression = false, bool enableGzip = true, bool enableDeflate = true, int compressionLevel = 6, int maxMissedHeartbeats = 3})
const

Properties

bearerToken → String?
final
compressionLevel → int
final
connectionTimeout → Duration?
final
enableCompression → bool
final
enableDeflate → bool
final
enableGzip → bool
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
heartbeatInterval → Duration?
final
maxMissedHeartbeats → int
final
oauthConfig → OAuthConfig?
final
oauthToken → OAuthToken?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverUrl → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited