StreamableHttpTransportConfig class final

Inheritance
Annotations
  • @immutable

Constructors

StreamableHttpTransportConfig({required String baseUrl, Map<String, String>? headers, Duration? timeout, int? maxConcurrentRequests, bool? useHttp2, OAuthConfig? oauthConfig, bool enableCompression = false, Duration? heartbeatInterval, int maxMissedHeartbeats = 3, bool terminateOnClose = true})
const

Properties

baseUrl → String
final
enableCompression → bool
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
heartbeatInterval → Duration?
final
maxConcurrentRequests → int?
final
maxMissedHeartbeats → int
final
oauthConfig → OAuthConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminateOnClose → bool
final
timeout → Duration?
final
useHttp2 → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited