StringElicitationField class
A free-text string field. Carries an optional defaultValue (SEP-1034).
- Inheritance
-
- Object
- ElicitationFieldSchema
- StringElicitationField
- Annotations
-
- @immutable
Constructors
- StringElicitationField({String? title, String? description, String? defaultValue, String? format, int? minLength, int? maxLength})
-
const
-
StringElicitationField.fromJson(Map<
String, dynamic> json) -
factory
Properties
- defaultValue → String?
-
final
- description → String?
-
Optional description (
description).finalinherited - format → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
final
- minLength → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional display title (
title).finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited