Task class
A task handle / detailed state as returned by a CreateTaskResult or a
tasks/get response.
Constructors
-
Task({required String taskId, required TaskStatus status, required String createdAt, required String lastUpdatedAt, String? statusMessage, int? ttlMs, int? pollIntervalMs, Map<
String, dynamic> ? inputRequests, Map<String, dynamic> ? result, Map<String, dynamic> ? error}) -
const
-
Task.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → String
-
final
-
error
→ Map<
String, dynamic> ? -
failed: the JSON-RPC error object.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
inputRequests
→ Map<
String, dynamic> ? -
input_required: server→client requests keyed by id.final - isTerminal → bool
-
no setter
- lastUpdatedAt → String
-
final
- pollIntervalMs → int?
-
final
-
result
→ Map<
String, dynamic> ? -
completed: the terminal result payload.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TaskStatus
-
final
- statusMessage → String?
-
final
- taskId → String
-
final
- ttlMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited