ToolMetadata class
Lightweight tool metadata (name + description only) Used for token-efficient LLM context in deferred loading mode
- Annotations
-
- @immutable
Constructors
- ToolMetadata({required String name, required String description})
-
const
-
ToolMetadata.fromMap(Map<
String, dynamic> map) -
Create from Map (for compatibility with McpClientManager.getTools())
factory
- ToolMetadata.fromTool(Tool tool)
-
Create from Tool object
factory
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override