ApiKeyValidator class
Simple API key validator
- Implemented types
Constructors
-
ApiKeyValidator(Map<
String, Map< _validApiKeys)String, dynamic> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasRequiredScopes(
List< String> tokenScopes, List<String> requiredScopes) → bool -
Check if token has required scopes
override
-
introspectToken(
String token) → Future< Map< String, dynamic> > -
Validate token introspection (RFC7662)
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateToken(
String token, {List< String> ? requiredScopes}) → Future<AuthResult> -
Validate a bearer token
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited