BooleanSchema class

Boolean primitive schema (SEP-1034 default).

Inheritance

Constructors

BooleanSchema({String? title, String? description, bool? defaultValue})
const
BooleanSchema.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → bool?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited