CallToolResult class
Tool call result.
Spec 2025-06-18 added structuredContent (optional JSON object that
pairs with Tool.outputSchema). Tools returning structured content
SHOULD also include the serialized JSON in a TextContent block for
backward compatibility with clients that don't read structuredContent.
Constructors
Properties
-
content
→ List<
Content> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool?
-
final
- isStreaming → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
structuredContent
→ Map<
String, dynamic> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited