ClientSession class
Client session information
Constructors
-
ClientSession({required String id, required DateTime connectedAt, Map<
String, dynamic> metadata = const {}, dynamic transport})
Properties
-
accessTokens
↔ Map<
String, Map< ?String, dynamic> > -
getter/setter pair
- authContext ↔ AuthContext?
-
getter/setter pair
- authToken ↔ String?
-
getter/setter pair
-
capabilities
↔ Map<
String, dynamic> ? -
getter/setter pair
- connectedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isInitialized ↔ bool
-
getter/setter pair
- logLevel ↔ String?
-
getter/setter pair
-
metadata
→ Map<
String, dynamic> -
final
- negotiatedProtocolVersion ↔ String?
-
getter/setter pair
-
pendingAuthCodes
↔ Map<
String, Map< ?String, dynamic> > -
getter/setter pair
-
roots
↔ List<
Map< String, dynamic> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transport ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited