DeprecationInfo class
Deprecation information
- Annotations
-
- @immutable
Constructors
- DeprecationInfo({required String version, required String reason, String? replacement, String? removalVersion})
-
const
-
DeprecationInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
Reason for deprecation
final
- removalVersion → String?
-
Planned removal version
final
- replacement → String?
-
Recommended replacement tool
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Version when the tool was deprecated
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited