NumberSchema class

Number / integer primitive schema (SEP-1034 default).

Inheritance

Constructors

NumberSchema({bool integer = false, String? title, String? description, num? minimum, num? maximum, num? defaultValue})
const
NumberSchema.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → num?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
integer → bool
When true the schema emits type: "integer", otherwise type: "number".
final
maximum → num?
final
minimum → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited