ProgressNotification class
Progress notification data (2025-03-26)
- Annotations
-
- @immutable
Constructors
- ProgressNotification({required String progressToken, required double progress, double? total})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- progress → double
-
final
- progressToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited