PromptArgument class

Prompt argument definition

Constructors

PromptArgument({required String name, required String description, bool required = false, String? defaultValue})
PromptArgument.fromJson(Map<String, dynamic> json)
Construct from the spec JSON shape — convenient for callers that don't want to import this typed class (e.g., generic adapters).
factory

Properties

defaultValue String?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited