ResourceLinkContent class
Resource link content (spec 2025-06-18+) — a tool result that points to a server resource by URI without inlining the content.
Constructors
Properties
-
annotations
→ Map<
String, dynamic> ? -
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
meta
→ Map<
String, dynamic> ? -
final
- mimeType → String?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited