ResourceUsage class

Resource usage indicators

Annotations
  • @immutable

Constructors

ResourceUsage({String cpu = 'low', String memory = 'low', String network = 'low', String disk = 'low'})
const
ResourceUsage.fromJson(Map<String, dynamic> json)
factory

Properties

cpu → String
CPU usage level (low, medium, high)
final
disk → String
Disk usage level (low, medium, high)
final
hashCode → int
The hash code for this object.
no setterinherited
memory → String
Memory usage level (low, medium, high)
final
network → String
Network usage level (low, medium, high)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited