SseTransportConfig class final
- Inheritance
-
- Object
- TransportConfig
- SseTransportConfig
- Annotations
-
- @immutable
Constructors
Properties
- authToken → String?
-
Authentication token for secure connections
final
- endpoint → String
-
The endpoint path for SSE connections
final
-
fallbackPorts
→ List<
int> -
Fallback ports to try if the primary port is unavailable
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
The host to bind to
final
- messagesEndpoint → String
-
The endpoint path for message sending
final
-
middleware
→ List<
Middleware> -
Custom middleware to apply
final
- port → int
-
The port to listen on
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited