StringSchema class

String primitive schema (SEP-1034 default).

Inheritance

Constructors

StringSchema({String? title, String? description, int? minLength, int? maxLength, String? format, String? defaultValue})
const
StringSchema.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue String?
final
description String?
final
format String?
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int?
final
minLength int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited