ToolAnnotationBuilder class

Tool annotation builder for creating standard annotations

Constructors

ToolAnnotationBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Map<String, dynamic>
Build the annotations map
category(String category) ToolAnnotationBuilder
Set tool category
custom(String key, dynamic value) ToolAnnotationBuilder
Add custom annotation
deprecated(DeprecationInfo info) ToolAnnotationBuilder
Mark tool as deprecated
destructive([bool value = true]) ToolAnnotationBuilder
Mark tool as destructive
estimatedDuration(int seconds) ToolAnnotationBuilder
Set estimated execution duration in seconds
examples(List<String> examples) ToolAnnotationBuilder
Add usage examples
experimental([bool value = true]) ToolAnnotationBuilder
Mark tool as experimental
minApiVersion(String version) ToolAnnotationBuilder
Set minimum required API version
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
priority(ToolPriority priority) ToolAnnotationBuilder
Set tool priority
readOnly([bool value = true]) ToolAnnotationBuilder
Mark tool as read-only
requiredPermissions(List<String> permissions) ToolAnnotationBuilder
Set required permissions
requiresConfirmation([bool value = true]) ToolAnnotationBuilder
Mark tool as requiring confirmation
resourceUsage(ResourceUsage usage) ToolAnnotationBuilder
Set resource usage information
supportsCancellation([bool value = true]) ToolAnnotationBuilder
Mark tool as supporting cancellation
supportsProgress([bool value = true]) ToolAnnotationBuilder
Mark tool as supporting progress
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited