TransportConfig class sealed
Configuration for transport connections
- Annotations
-
- @immutable
Constructors
-
TransportConfig.sse({String endpoint, String messagesEndpoint, String host, int port, List<
int> fallbackPorts, String? authToken, List<Middleware> middleware}) -
Configuration for SSE transport
constfactory
- TransportConfig.stdio()
-
Configuration for STDIO transport
constfactory
-
TransportConfig.streamableHttp({String host, int port, String endpoint, String messagesEndpoint, List<
int> fallbackPorts, String? authToken, bool isJsonResponseEnabled, List<Middleware> middleware}) -
Configuration for Streamable HTTP transport
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited